# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from knack.help_files import helps


helps['hcs'] = """
    type: group
    short-summary: Commands to manage HCS.
"""

helps['hcs browse'] = """
    type: group
    short-summary: Open HCS UI
"""

helps['hcs create'] = """
    type: command
    short-summary: Create a HCS cluster.
    examples:
        - name: Create a cluster with an external endpoint.
          text: |
            az hcs create -g test --name test --email example@hashicorp.com --external-endpoint enabled
        - name: Create a cluster with a specific version.
          text: |
            az hcs create -g test --name test --email example@hashicorp.com --consul-version v1.8.0
        - name: Create a cluster with the annual plan.
          text: |
            az hcs create -g test --name test --email example@hashicorp.com --plan-name annual
"""

helps['hcs delete'] = """
    type: command
    short-summary: Delete a HCS cluster.
"""

helps['hcs list'] = """
    type: command
    short-summary: List HCS Cluster details.
"""

helps['hcs list-versions'] = """
    type: command
    short-summary: List available consul versions.
"""

helps['hcs list-regions'] = """
    type: command
    short-summary: List regions that support HCS.
"""

helps['hcs update'] = """
    short-summary: Update HCS Cluster details.
    examples:
        - name: Update to a newer version of Consul.
          text: |
            az hcs update -g test --name test --consul-version v1.8.0
"""

helps['hcs get-config'] = """
    type: command
    short-summary: Get HCS cluster config.
"""

helps['hcs create-token'] = """
    type: command
    short-summary: Create HCS master token. Note that a new token will be created every time this command is invoked.
    examples:
        - name: Create a master token.
          text: |
            az hcs create-token -g test --name test
        - name: Create token and output a Kubernetes secret to apply your Kubernetes cluster.
          text: |
            az hcs create-token -g test --name test --output-kubernetes-secret | kubectl apply -f -
"""

helps['hcs generate-kubernetes-secret'] = """
    type: command
    short-summary: Generate a Kubernetes secret with credentials for the HCS cluster.
    examples:
        - name: Generate and apply the secret to your Kubernetes cluster.
          text: |
            az hcs generate-kubernetes-secret -g test --name test | kubectl apply -f -
        - name: Generate Kubernetes secret and save it to a file.
          text: |
            az hcs generate-kubernetes-secret -g test --name test > hcs-secret.yaml
"""

helps['hcs generate-helm-values'] = """
    type: command
    short-summary: Generate a Helm values file to install Consul on Kubernetes with HCS as an external server cluster.
    examples:
        - name: Generate a Helm config file and run Helm install.
          text: |
            az hcs generate-helm-values -g test --name test --aks-cluster-name test-k8s > config.yaml
            helm install -f config.yaml hashicorp/consul
"""

helps['hcs show'] = """
    short-summary: Show HCS Cluster details.
    examples:
        - name: Show properties of an HCS Cluster.
          text: |
            az hcs show -g test --name test
"""
